@@ -807,14 +807,27 @@ ts_get_appendrelinfo(PlannerInfo *root, Index rti, bool missing_ok)
  * This function was moved to postgres main in PG13 but was removed
  * again in PG15. So we use our own implementation for PG15+.
  */
-Expr *
-ts_find_em_expr_for_rel(EquivalenceClass *ec, RelOptInfo *rel)
+EquivalenceMember *
+ts_find_em_for_rel(EquivalenceClass *ec, RelOptInfo *rel)
 {
+	EquivalenceMember *em;
+#if PG18_GE
+	/* Use specialized iterator to include child ems.
+	 *
+	 * https://github.com/postgres/postgres/commit/d69d45a5
+	 */
+	EquivalenceMemberIterator it;
+
+	setup_eclass_member_iterator(&it, ec, bms_make_singleton(rel->relid));
+	while ((em = eclass_member_iterator_next(&it)) != NULL)
+	{
+#else
 	ListCell *lc_em;
 
 	foreach (lc_em, ec->ec_members)
 	{
-		EquivalenceMember *em = lfirst(lc_em);
+		em = lfirst(lc_em);
+#endif
 
 		if (bms_is_subset(em->em_relids, rel->relids) && !bms_is_empty(em->em_relids))
 		{
@@ -823,14 +836,21 @@ ts_find_em_expr_for_rel(EquivalenceClass *ec, RelOptInfo *rel)
 			 * taken entirely from this relation, we'll be content to choose
 			 * any one of those.
 			 */
-			return em->em_expr;
+			return em;
 		}
 	}
 
-	/* We didn't find any suitable equivalence class expression */
+	/* We didn't find any suitable equivalence class member */
 	return NULL;
 }
 
+Expr *
+ts_find_em_expr_for_rel(EquivalenceClass *ec, RelOptInfo *rel)
+{
+	EquivalenceMember *em = ts_find_em_for_rel(ec, rel);
+	return em ? em->em_expr : NULL;
+}
+
 bool
 ts_has_row_security(Oid relid)
 {
@@ -972,16 +992,28 @@ ts_subtract_integer_from_now(PG_FUNCTION_ARGS)
 	const Dimension *dim = hyperspace_get_open_dimension(ht->space, 0);
 
 	if (!dim)
-		elog(ERROR, "hypertable has no open partitioning dimension");
+	{
+		ereport(ERROR,
+				(errcode(ERRCODE_OBJECT_NOT_IN_PREREQUISITE_STATE),
+				 errmsg("hypertable has no open partitioning dimension")));
+	}
 
 	Oid partitioning_type = ts_dimension_get_partition_type(dim);
 
 	if (!IS_INTEGER_TYPE(partitioning_type))
-		elog(ERROR, "hypertable has no integer partitioning dimension");
+	{
+		ereport(ERROR,
+				(errcode(ERRCODE_OBJECT_NOT_IN_PREREQUISITE_STATE),
+				 errmsg("hypertable has no integer partitioning dimension")));
+	}
 
 	Oid now_func = ts_get_integer_now_func(dim, true);
 	if (!OidIsValid(now_func))
-		elog(ERROR, "could not find valid integer_now function for hypertable");
+	{
+		ereport(ERROR,
+				(errcode(ERRCODE_OBJECT_NOT_IN_PREREQUISITE_STATE),
+				 errmsg("could not find valid integer_now function for hypertable")));
+	}
 
 	int64 res = ts_sub_integer_from_now(lag, partitioning_type, now_func);
 	ts_cache_release(&hcache);
@@ -1805,33 +1837,10 @@ ts_update_placeholder(PG_FUNCTION_ARGS)
 /*
  * Get relation information from the syscache in one call.
  *
- * Returns relkind and access method used. Both are non-optional.
+ * Returns relid and relkind. All are non-optional.
  */
 void
-ts_get_rel_info(Oid relid, Oid *amoid, char *relkind)
-{
-	HeapTuple tuple;
-	Form_pg_class cform;
-
-	tuple = SearchSysCache1(RELOID, ObjectIdGetDatum(relid));
-
-	if (!HeapTupleIsValid(tuple))
-		elog(ERROR, "cache lookup failed for relation %u", relid);
-
-	cform = (Form_pg_class) GETSTRUCT(tuple);
-	*amoid = cform->relam;
-	*relkind = cform->relkind;
-	ReleaseSysCache(tuple);
-}
-
-/*
- * Get relation information from the syscache in one call.
- *
- * Returns relid, relkind and access method used. All are non-optional.
- */
-void
-ts_get_rel_info_by_name(const char *relnamespace, const char *relname, Oid *relid, Oid *amoid,
-						char *relkind)
+ts_get_rel_info_by_name(const char *relnamespace, const char *relname, Oid *relid, char *relkind)
 {
 	HeapTuple tuple;
 	Form_pg_class cform;
@@ -1844,7 +1853,6 @@ ts_get_rel_info_by_name(const char *relnamespace, const char *relname, Oid *reli
 
 	cform = (Form_pg_class) GETSTRUCT(tuple);
 	*relid = cform->oid;
-	*amoid = cform->relam;
 	*relkind = cform->relkind;
 	ReleaseSysCache(tuple);
 }
@@ -1903,7 +1911,7 @@ relation_set_reloption_impl(Relation rel, List *options, LOCKMODE lockmode)
 
 	/* Generate new proposed reloptions (text array) */
 	Datum newOptions =
-		transformRelOptions(isnull ? (Datum) 0 : datum, options, NULL, NULL, false, false);
+		transformRelOptions(isnull ? UnassignedDatum : datum, options, NULL, NULL, false, false);
 	(void) heap_reloptions(rel->rd_rel->relkind, newOptions, true);
 
 	if (newOptions)
